#!/bin/bash
######################################################################
#
#   tcar - The CentOS Artwork Repository
#   Copyright © 2014 The CentOS Artwork SIG
#
#   This program is free software; you can redistribute it and/or
#   modify it under the terms of the GNU General Public License as
#   published by the Free Software Foundation; either version 2 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#   General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#   Alain Reguera Delgado <alain.reguera@gmail.com>
#   39 Street No. 4426 Cienfuegos, Cuba.
#
######################################################################

function locale {

    # Define flag controlling the way locale module produces
    # localization files.
    local LOCALE_FLAG_RECURSIVE="false"

    # Initialize module's actions.
    local ACTIONS=''

    # Initialize command-line arguments and interpret arguments and
    # options passed through command-line.
    local ARGUMENT='' ARGUMENTS=''; locale_getOptions "${@}"

    # Verify the current locale information to avoid English messages
    # from being localized to themselves. The English language is used
    # as reference to write translatable strings inside the source
    # files.
    if [[ ${SCRIPT_LANG_LC} =~ ^C$ ]];then
        tcar_printMessage "`gettext "The C locale cannot be localized to itself."`" --as-error-line
    fi

    # Process arguments passed to locale module, based on whether they
    # are files or directories.
    for ARGUMENT in ${ARGUMENTS};do

        # Sanitate non-option arguments to be sure they match the
        # directory conventions established by tcar.sh script
        # against source directory locations in the working copy.
        ARGUMENT=$(tcarlib_printPath "${ARGUMENT}")

        # Verify configuration files existence. We cannot process a
        # configuration file that doesn't exist.
        tcarlib_checkFiles -e ${ARGUMENT}

        # Reset working directory based on configuration files. This
        # make the creation of several workplaces possible.
        TCAR_WORKDIR=$(tcarlib_printWorkdir "${ARGUMENT}")

        # Check working directory based on configuration files.
        tcarlib_checkWorkdir "${ARGUMENT}"

        if [[ -f ${ARGUMENT} ]];then
            tcarlib_setModuleEnvironment -m "files" -t "child" -g "${ARGUMENT}"
        elif [[ -d ${ARGUMENT} ]];then
            tcarlib_setModuleEnvironment -m "directories" -t "child" -g "${ARGUMENT}"
        else
            tcar_printMessage "`gettext "The argument provided isn't valid."`" --as-error-line
        fi

    done

}
