#!/bin/bash
######################################################################
#
#   tcar - The CentOS Artwork Repository
#   Copyright © 2014 The CentOS Artwork SIG
#
#   This program is free software; you can redistribute it and/or
#   modify it under the terms of the GNU General Public License as
#   published by the Free Software Foundation; either version 2 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#   General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#   Alain Reguera Delgado <alain.reguera@gmail.com>
#   39 Street No. 4426 Cienfuegos, Cuba.
#
######################################################################

# Initialize files processing based on the information provided by the
# configuration files passed in the command-line.
function files {

    local CONFIGURATION=${1}

    tcarlib_checkFiles -efm '\.conf$' "${CONFIGURATION}"

    local MOTIF=$(tcar_printPathComponent ${CONFIGURATION} --motif)

    local -a SECTIONS; tcarlib_setConfigSections

    local COUNT=0

    # Process sections found in the configuration file.
    while [[ ${COUNT} -lt ${#SECTIONS[*]} ]];do

        # Define value of the configuration section being processed.
        local SECTION=${SECTIONS[${COUNT}]}

        local RENDER_TARGET_DIR=''  ; files_setConfigOption 'render-dir'
        local RENDER_TARGET=''      ; files_setConfigOption 'render-file'
        local RENDER_LOGIC=''       ; files_setConfigOption 'render-logic'
        local -a RENDER_FROM        ; files_setConfigOption 'render-from'
        local -a LOCALE_FROM        ; files_setConfigOption 'locale-from'
        local RENDER_TYPE=''        ; files_setConfigOption 'render-type'
        local RELEASE=''            ; files_setConfigOption 'release'
        local MAJOR_RELEASE=''      ; files_setConfigOption 'release-major'

        tcarlib_setParentDir "${RENDER_TARGET}"

        tcarlib_setModuleEnvironment -m ${RENDER_TYPE} -t 'child'

        COUNT=$(( ++COUNT ))

        # Reset array variable related to section content to avoid
        # undesired concatenations of their values between different
        # sections blocks.
        unset RENDER_FROM
        unset LOCALE_FROM

    done

    # Reset array variables to avoid undesired concatenations between
    # configuration files.
    unset SECTIONS

    # Execute make files to final files produced.
    tcarlib_setModuleEnvironment -m 'make' -t 'child'

}
