#!/bin/bash
######################################################################
#
#   tcar - The CentOS Artwork Repository
#   Copyright © 2014 The CentOS Artwork SIG
#
#   This program is free software; you can redistribute it and/or
#   modify it under the terms of the GNU General Public License as
#   published by the Free Software Foundation; either version 2 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#   General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#   Alain Reguera Delgado <alain.reguera@gmail.com>
#   39 Street No. 4426 Cienfuegos, Cuba.
#
######################################################################

# Standardize the way translation file in PO format is applied to XML
# file (e.g., .docbook, .svg) in order to produce the translated
# instance of it.
function files_setLocalizedXml {

    if [[ ! -f ${PO_FILE} ]];then
        if [[ ! -f ${SOURCE_INSTANCE} ]];then
            ln -s ${RENDER_FROM_FILE} ${SOURCE_INSTANCE}
        fi
        return
    fi

    # Move the directory stack to final location before processing
    # source file in order for relative calls (e.g., image files)
    # inside the source files can be found by xml2po and no warning be
    # printed from it.
    pushd ${RENDER_TARGET_DIR} > /dev/null

    # Create the localized instance from design model.
    xml2po -a -l ${SCRIPT_LANG_LC} -p ${PO_FILE} -o ${SOURCE_INSTANCE} ${RENDER_FROM_FILE}

    # Remove .xml2po.mo temporal file.
    [[ -f ./.xml2po.mo ]] && rm ./.xml2po.mo

    # xml2po (gnome-doc-utils-0.18.1-1.el6.noarch) bug? For some
    # reason xml2po is not adding/replacing the lang attribute.  This
    # make intrinsic docbook constructions (e.g., navigation, table of
    # contents, chapters, etc.) be rendered without localization.
    if [[ ${SCRIPT_LANG_LL} != 'en' ]];then
        sed -i -r "s/[[:space:]]+lang=\"[[:alpha:]]+\">/ lang=\"${SCRIPT_LANG_LL}\">/" ${SOURCE_INSTANCE}
    fi

    # Return to previous location.
    popd > /dev/null

}
