#!/bin/bash
######################################################################
#
#   tcar - The CentOS Artwork Repository
#   Copyright © 2014 The CentOS Artwork SIG
#
#   This program is free software; you can redistribute it and/or
#   modify it under the terms of the GNU General Public License as
#   published by the Free Software Foundation; either version 2 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#   General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#   Alain Reguera Delgado <alain.reguera@gmail.com>
#   39 Street No. 4426 Cienfuegos, Cuba.
#
######################################################################

# Standardize content rendition.
function render {

    # Initialize command-line arguments and interpret arguments and
    # options passed through command-line.
    local ARGUMENT='' ARGUMENTS=''; render_getOptions "${@}"

    # Define the action value. This is the location where actions will
    # take place.
    for ARGUMENT in ${ARGUMENTS};do

        # Sanitate non-option arguments to be sure they match the
        # directory conventions established by tcar.sh script
        # against source directory locations in the working copy.
        ARGUMENT=$(tcarlib_printPath "${ARGUMENT}")

        # Verify configuration files existence. We cannot process a
        # configuration file that doesn't exist.
        tcarlib_checkFiles -e ${ARGUMENT}

        # Reset working directory based on configuration files. This
        # make the creation of several workplaces possible.
        TCAR_WORKDIR=$(tcarlib_printWorkdir "${ARGUMENT}")

        # Check working directory based on configuration files.
        tcarlib_checkWorkdir "${ARGUMENT}"

        if [[ -d ${ARGUMENT} ]];then
            tcarlib_setModuleEnvironment -m 'directories' -t 'child' -g ${ARGUMENT}
        elif [[ -f ${ARGUMENT} || -h ${ARGUMENT} ]];then
            tcarlib_setModuleEnvironment -m 'files' -t 'child' -g ${ARGUMENT}
        else
            tcar_printMessage "${ARGUMENT} `gettext "isn't supported."`" --as-error-line
        fi

    done

}
